@@ -23,7 +23,8 @@
       READ (*,*) IWS
 
       CALL GROPN( IWS )
-      CALL SGLSET( 'LSOFTF', .TRUE. )
+*      CALL SGLSET( 'LSOFTF', .TRUE. )
+      CALL SGLSET( 'LSOFTF', .FALSE. )
       CALL GRFRM
 
       CALL GRSWND( XMIN, XMAX, YMIN, YMAX )
