@@ -8,7 +8,6 @@
       INTEGER   IMAGE(*)
       REAL      WPX(*), WPY(*)
       LOGICAL   LFCATR, LWDATR, LCLATR, LTNATR, LIMATR, LPTATR
-      LOGICAL   LFCMOD
       CHARACTER COBJ*(*), COMM*(*)
 
       LOGICAL   LWAIT, LWAIT0, LWAIT1, LKEY, LDUMP, LALT,
@@ -20,6 +19,9 @@
       REAL      RIMGCMP
       CHARACTER CNOPN*26
 
+      INTEGER IDMPDGT
+      LOGICAL LSTDOUT
+
       SAVE
 
       DATA      CNOPN / 'WORKSTATION IS NOT OPENED.' /
@@ -29,6 +31,7 @@
 
       CALL SGIGET('IWS', JWS)
       CALL SWIGET('IWS', IWS)
+      CALL SWIGET('IFL', IFL)
 
       CMSG='GRPH1 : STARTED / IWS = ##.'
       CALL CHNGI(CMSG,'##',JWS,'(I2)')
@@ -36,7 +39,7 @@
 
 *     / DEVICE DEPENDENT PARAMETERS /
 
-      IF (IWS.EQ.1 .OR. IWS.EQ.2 .OR. IWS.EQ.4) THEN
+      IF (IWS.EQ.1 .OR. IWS.EQ.2) THEN
 
         CALL SWIGET('IWIDTH ', IWIDTH)
         CALL SWIGET('IHEIGHT', IHEIGH)
@@ -44,6 +47,7 @@
         CALL SWLGET('LFGBG  ', LFGBG )
         CALL SWCGET('FNAME  ', COUT  )
         CALL SWCGET('TITLE  ', CTTL  )
+        CALL SWIGET('IDMPDGT ', IDMPDGT)
 
         CALL SWCMLL
         CALL SWQFNM('CLRMAP ', CLRMAP)
@@ -68,8 +72,6 @@
 
       END IF
 
-      IF (IWS.EQ.1) THEN
-
         CALL SWIGET('IPOSX  ', IPOSX )
         CALL SWIGET('IPOSY  ', IPOSY )
         CALL SWLGET('LWAIT  ', LWAIT )
@@ -78,45 +80,7 @@
         CALL SWLGET('LKEY   ', LKEY  )
         CALL SWLGET('LALT   ', LALT  )
         CALL SWLGET('LDUMP  ', LDUMP )
-
-        CALL SWQFNM('BITMAP ', CBTMAP)
-        IF (CBTMAP.EQ.' ') THEN
-          CALL MSGDMP('E','SWDOPN','BITMAP FILE DOES NOT EXIST.')
-        END IF
-
-        CALL ZXDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
-     +       LWAIT, LWAIT0, LWAIT1, LKEY, LALT, LDUMP, LFGBG,
-     +       CLRMAP, CBTMAP, COUT, CTTL)
-
-      ELSE IF (IWS.EQ.2) THEN
-
-        CALL SWLGET('LCOLOR ', LCOLOR)
-        CALL SWLGET('LSEP   ', LSEP  )
-        CALL SWLGET('LPRINT ', LPRINT)
-        CALL SWCGET('LPR    ', CLPR  )
-
-        CALL Z1DOPN(IWIDTH, IHEIGH, LCOLOR, LSEP, LPRINT,
-     +       CLRMAP, COUT, CTTL, CLPR)
-
-      ELSE IF (IWS.EQ.3) THEN
-
-        CALL SWLGET('LWAIT  ', LWAIT)
-        CALL GLIGET('NLNSIZE',NLNSZ0)
-        CALL SWIGET('NLNSIZE',NLNSIZ)
-        CALL GLISET('NLNSIZE',NLNSIZ)
-
-        CALL ZTDOPN(LWAIT)
-
-      ELSE IF (IWS.EQ.4) THEN
-
-        CALL SWIGET('IPOSX  ', IPOSX )
-        CALL SWIGET('IPOSY  ', IPOSY )
-        CALL SWLGET('LWAIT  ', LWAIT )
-        CALL SWLGET('LWAIT0 ', LWAIT0)
-        CALL SWLGET('LWAIT1 ', LWAIT1)
-        CALL SWLGET('LALT   ', LALT  )
-        CALL SWLGET('LKEY   ', LKEY  )
-        CALL SWLGET('LDUMP  ', LDUMP )
+        CALL SWLGET('LSTDOT ', LSTDOT )
 
         CALL SWQFNM('BITMAP ', CBTMAP)
         IF (CBTMAP.EQ.' ') THEN
@@ -124,19 +88,20 @@
         END IF
 
         CALL SWLGET('LWND   ', LWND  )
-
         CALL SWCGET('CIMGFMT ', CIMGFMT)
         CALL SWRGET('RIMGCMP ', RIMGCMP)
 
-        CALL ZGDOPN(IWIDTH, IHEIGH, IPOSX, IPOSY,
-     +       LWAIT, LWAIT0, LWAIT1, LALT, LKEY, LDUMP, LWND, LFGBG,
-     +       CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT, CTTL)
-      END IF
-      LOPEN = .TRUE.
+        CALL ZGDOPN(IWS, IWIDTH, IHEIGH, IPOSX, IPOSY, IDMPDGT,
+     +       LWAIT, LWAIT0, LWAIT1, LALT, LSTDOT,LKEY, LDUMP, LWND,
+     +       LFGBG,IFL,CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT,
+     +       CTTL)
 
-      IF (IWS.NE.3) THEN
-      CALL SGCLST(CLRMAP)
-      END IF
+*        CALL SWLGET('LCOLOR ', LCOLOR)
+*        CALL SWLGET('LSEP   ', LSEP  )
+*        CALL SWLGET('LPRINT ', LPRINT)
+*        CALL SWCGET('LPR    ', CLPR  )
+
+      LOPEN = .TRUE.
 
       RETURN
 *-----------------------------------------------------------------------
@@ -144,13 +109,8 @@
 
 *     / ( DEACTIVATE AND ) CLOSE WORKSTATION /
 
-      IF (IWS.EQ.1) CALL ZXDCLS
-      IF (IWS.EQ.2) CALL Z1DCLS
-      IF (IWS.EQ.3) THEN
-        CALL ZTDCLS
-        CALL GLISET('NLNSIZE',NLNSZ0)
-      END IF
-      IF (IWS.EQ.4) CALL ZGDCLS
+      CALL ZGDCLS
+
       CMSG='GRPH1 : TERMINATED.'
       CALL MSGDMP('M','SWDCLS',CMSG)
       LOPEN = .FALSE.
@@ -165,10 +125,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWPOPN', CNOPN)
-      IF (IWS.EQ.1) CALL ZXPOPN
-      IF (IWS.EQ.2) CALL Z1POPN
-      IF (IWS.EQ.3) CALL ZTPOPN
-      IF (IWS.EQ.4) CALL ZGPOPN
+      CALL ZGPOPN
 
       RETURN
 *-----------------------------------------------------------------------
@@ -183,10 +140,7 @@
       CALL CHNGI(CMSG,'###',NPAGE,'(I3)')
       CALL MSGDMP('M','SWPCLS',CMSG)
 
-      IF (IWS.EQ.1) CALL ZXPCLS
-      IF (IWS.EQ.2) CALL Z1PCLS
-      IF (IWS.EQ.3) CALL ZTPCLS(LWAIT)
-      IF (IWS.EQ.4) CALL ZGPCLS
+      CALL ZGPCLS
 
       RETURN
 *-----------------------------------------------------------------------
@@ -198,10 +152,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWOOPN', CNOPN)
-      IF (IWS.EQ.1) CALL ZXOOPN(COBJ, COMM)
-      IF (IWS.EQ.2) CALL Z1OOPN(COBJ, COMM)
-      IF (IWS.EQ.3) CALL ZTOOPN(COBJ, COMM)
-      IF (IWS.EQ.4) CALL ZGOOPN(COBJ, COMM)
+      CALL ZGOOPN(COBJ, COMM)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -211,14 +162,9 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWOCLS', CNOPN)
-      IF (IWS.EQ.1) CALL ZXOCLS(COBJ)
-      IF (IWS.EQ.2) CALL Z1OCLS(COBJ)
-      IF (IWS.EQ.3) CALL ZTOCLS(COBJ)
-      IF (IWS.EQ.4) CALL ZGOCLS(COBJ)
+      CALL ZGOCLS(COBJ)
 
       RETURN
-
-
 *-----------------------------------------------------------------------
 *     FULL COLOR (2000/12/10 TEST)
 *-----------------------------------------------------------------------
@@ -226,10 +172,7 @@
 
 *     / INQUIRE FULL COLOR CAPABILITY /
 
-      IF (IWS.EQ.1) CALL ZXQFCC(LFCATR)
-      IF (IWS.EQ.2) LFCATR = .TRUE.
-      IF (IWS.EQ.3) LFCATR = .FALSE.
-      IF (IWS.EQ.4) LFCATR = .TRUE.
+      LFCATR = .TRUE.
 
       RETURN
 *-----------------------------------------------------------------------
@@ -237,26 +180,19 @@
 
 *     / SET FULL COLOR MODE /
 
-       IF (IWS.EQ.1) CALL ZXSFCM(LFCMOD)
-       IF (IWS.EQ.2) CALL Z1SFCM(LFCMOD)
-*      IF (IWS.EQ.3) CALL ZTSFCM(LFCMOD)
-       IF (IWS.EQ.4) CALL ZGSFCM(LFCMOD)
+      CALL ZGSFCM(LFCMOD)
 
       RETURN
 *-----------------------------------------------------------------------
 *     LINE
 *-----------------------------------------------------------------------
-
       ENTRY SWSWDI(IWDIDX)
 
 *     / SET LINE WIDTH INDEX /
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWSWDI', CNOPN)
-      IF (IWS.EQ.1) CALL ZXSWDI(IWDIDX)
-      IF (IWS.EQ.2) CALL Z1SWDI(IWDIDX)
-      IF (IWS.EQ.3) CALL ZTSWDI(IWDIDX)
-      IF (IWS.EQ.4) CALL ZGSWDI(IWDIDX)
+      CALL ZGSWDI(IWDIDX)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -266,11 +202,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWSCLI', CNOPN)
-
-      IF (IWS.EQ.1) CALL ZXSCLI(ICLIDX)
-      IF (IWS.EQ.2) CALL Z1SCLI(ICLIDX)
-      IF (IWS.EQ.3) CALL ZTSCLI(ICLIDX)
-      IF (IWS.EQ.4) CALL ZGSCLI(ICLIDX)
+      CALL ZGSCLI(ICLIDX)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -278,10 +210,7 @@
 
 *     / SET LINE COLOR IN 24BIT RGB /
 
-      IF (IWS.EQ.1) CALL ZXSLCL(ICOLOR)
-      IF (IWS.EQ.2) CALL Z1SLCL(ICOLOR)
-*      IF (IWS.EQ.3) CALL ZTSLCL(NCOLOR)
-      IF (IWS.EQ.4) CALL ZGSLCL(ICOLOR)
+      CALL ZGSLCL(ICOLOR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -293,10 +222,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWGOPN', CNOPN)
-      IF (IWS.EQ.1) CALL ZXGOPN
-      IF (IWS.EQ.2) CALL Z1GOPN
-      IF (IWS.EQ.3) CALL ZTGOPN
-      IF (IWS.EQ.4) CALL ZGGOPN
+      CALL ZGGOPN
 
       RETURN
 *-----------------------------------------------------------------------
@@ -306,10 +232,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWGMOV', CNOPN)
-      IF (IWS.EQ.1) CALL ZXGMOV(WX,WY)
-      IF (IWS.EQ.2) CALL Z1GMOV(WX,WY)
-      IF (IWS.EQ.3) CALL ZTGMOV(WX,WY)
-      IF (IWS.EQ.4) CALL ZGGMOV(WX,WY)
+      CALL ZGGMOV(WX,WY)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -319,10 +242,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWGPLT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXGPLT(WX,WY)
-      IF (IWS.EQ.2) CALL Z1GPLT(WX,WY)
-      IF (IWS.EQ.3) CALL ZTGPLT(WX,WY)
-      IF (IWS.EQ.4) CALL ZGGPLT(WX,WY)
+      CALL ZGGPLT(WX,WY)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -334,10 +254,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWGCLS', CNOPN)
-      IF (IWS.EQ.1) CALL ZXGCLS
-      IF (IWS.EQ.2) CALL Z1GCLS
-      IF (IWS.EQ.3) CALL ZTGCLS
-      IF (IWS.EQ.4) CALL ZGGCLS
+      CALL ZGGCLS
 
       RETURN
 *-----------------------------------------------------------------------
@@ -347,10 +264,7 @@
 
 *     / SET TONE COLOR IN 24BIT RGB /
 
-      IF (IWS.EQ.1) CALL ZXSTCL(ICOLOR)
-      IF (IWS.EQ.2) CALL Z1STCL(ICOLOR)
-*      IF (IWS.EQ.3) CALL ZTSTCL(ICOLOR)
-      IF (IWS.EQ.4) CALL ZGSTCL(ICOLOR)
+      CALL ZGSTCL(ICOLOR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -360,10 +274,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWGTON', CNOPN)
-      IF (IWS.EQ.1) CALL ZXGTON(NP,WPX,WPY,ITPAT)
-      IF (IWS.EQ.2) CALL Z1GTON(NP,WPX,WPY,ITPAT)
-      IF (IWS.EQ.3) CALL ZTGTON(NP,WPX,WPY,ITPAT)
-      IF (IWS.EQ.4) CALL ZGGTON(NP,WPX,WPY,ITPAT)
+      CALL ZGGTON(NP,WPX,WPY,ITPAT)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -376,13 +287,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
-      IF (IWS.EQ.1) CALL ZXIOPN(IWX, IWY, IMW, IMH)
-      IF (IWS.EQ.2) THEN
-        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
-        CALL Z1IOPN(IWX, IWY, IMW, IMH)
-      ENDIF
-      IF (IWS.EQ.3) CALL ZTIOPN(IWX, IWY, IMW, IMH)
-      IF (IWS.EQ.4) CALL ZGIOPN(IWX, IWY, IMW, IMH)
+      CALL ZGIOPN(IWX, IWY, IMW, IMH)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -392,20 +297,14 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWIDAT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXIDAT(IMAGE, NLEN)
-      IF (IWS.EQ.2) CALL Z1IDAT(IMAGE, NLEN)
-      IF (IWS.EQ.3) CALL ZTIDAT(IMAGE, NLEN)
-      IF (IWS.EQ.4) CALL ZGIDAT(IMAGE, NLEN)
+      CALL ZGIDAT(IMAGE, NLEN)
 
       RETURN
 *-----------------------------------------------------------------------
       ENTRY SWICLR(IMAGE, NLEN)
 
 *     / IMAGE DATA (FULL COLOR) /
-      IF (IWS.EQ.1) CALL ZXICLR(IMAGE, NLEN)
-      IF (IWS.EQ.2) CALL Z1ICLR(IMAGE, NLEN)
-*      IF (IWS.EQ.3) CALL ZTICLR(IMAGE, NLEN)
-      IF (IWS.EQ.4) CALL ZGICLR(IMAGE, NLEN)
+      CALL ZGICLR(IMAGE, NLEN)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -415,10 +314,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWICLS', CNOPN)
-      IF (IWS.EQ.1) CALL ZXICLS
-      IF (IWS.EQ.2) CALL Z1ICLS
-      IF (IWS.EQ.3) CALL ZTICLS
-      IF (IWS.EQ.4) CALL ZGICLS
+      CALL ZGICLS
 
       RETURN
 *-----------------------------------------------------------------------
@@ -430,10 +326,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWQPNT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXQPNT(WX,WY,MB)
-      IF (IWS.EQ.2) CALL Z1QPNT(WX,WY,MB)
-      IF (IWS.EQ.3) CALL ZTQPNT(WX,WY,MB)
-      IF (IWS.EQ.4) CALL ZGQPNT(WX,WY,MB)
+      CALL ZGQPNT(WX,WY,MB)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -445,10 +338,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWFINT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXFINT(WX, WY, IWX, IWY)
-      IF (IWS.EQ.2) CALL Z1FINT(WX, WY, IWX, IWY)
-      IF (IWS.EQ.3) CALL ZTFINT(WX, WY, IWX, IWY)
-      IF (IWS.EQ.4) CALL ZGFINT(WX, WY, IWX, IWY)
+      CALL ZGFINT(WX, WY, IWX, IWY)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -458,10 +348,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWIINT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXIINT(IWX, IWY, WX, WY)
-      IF (IWS.EQ.2) CALL Z1IINT(IWX, IWY, WX, WY)
-      IF (IWS.EQ.3) CALL ZTIINT(IWX, IWY, WX, WY)
-      IF (IWS.EQ.4) CALL ZGIINT(IWX, IWY, WX, WY)
+      CALL ZGIINT(IWX, IWY, WX, WY)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -471,10 +358,7 @@
 
 *     / INQUIRE LINE WIDTH CAPABILITY /
 
-      IF (IWS.EQ.1) CALL ZXQWDC(LWDATR)
-      IF (IWS.EQ.2) CALL Z1QWDC(LWDATR)
-      IF (IWS.EQ.3) CALL ZTQWDC(LWDATR)
-      IF (IWS.EQ.4) CALL ZGQWDC(LWDATR)
+      CALL ZGQWDC(LWDATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -484,10 +368,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWQCLC', CNOPN)
-      IF (IWS.EQ.1) CALL ZXQCLC(LCLATR)
-      IF (IWS.EQ.2) CALL Z1QCLC(LCLATR)
-      IF (IWS.EQ.3) CALL ZTQCLC(LCLATR)
-      IF (IWS.EQ.4) CALL ZGQCLC(LCLATR)
+      CALL ZGQCLC(LCLATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -495,10 +376,7 @@
 
 *     / INQUIRE HARD FILL CAPABILITY /
 
-      IF (IWS.EQ.1) CALL ZXQTNC(LTNATR)
-      IF (IWS.EQ.2) CALL Z1QTNC(LTNATR)
-      IF (IWS.EQ.3) CALL ZTQTNC(LTNATR)
-      IF (IWS.EQ.4) CALL ZGQTNC(LTNATR)
+      CALL ZGQTNC(LTNATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -506,10 +384,7 @@
 
 *     / INQUIRE BIT IMAGE CAPABILITY /
 
-      IF (IWS.EQ.1) CALL ZXQIMC(LIMATR)
-      IF (IWS.EQ.2) CALL Z1QIMC(LIMATR)
-      IF (IWS.EQ.3) CALL ZTQIMC(LIMATR)
-      IF (IWS.EQ.4) CALL ZGQIMC(LIMATR)
+      CALL ZGQIMC(LIMATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -517,10 +392,7 @@
 
 *     / INQUIRE MOUSE POINT CAPABILITY /
 
-      IF (IWS.EQ.1) CALL ZXQPTC(LPTATR)
-      IF (IWS.EQ.2) CALL Z1QPTC(LPTATR)
-      IF (IWS.EQ.3) CALL ZTQPTC(LPTATR)
-      IF (IWS.EQ.4) CALL ZGQPTC(LPTATR)
+      CALL ZGQPTC(LPTATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -530,10 +402,7 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWQRCT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
-      IF (IWS.EQ.2) CALL Z1QRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
-      IF (IWS.EQ.3) CALL ZTQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
-      IF (IWS.EQ.4) CALL ZGQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
+      CALL ZGQRCT(WSXMN,WSXMX,WSYMN,WSYMX,FACT)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -543,13 +412,9 @@
 
       IF (.NOT. LOPEN)
      +   CALL MSGDMP('E', 'SWSROT', CNOPN)
-      IF (IWS.EQ.1) CALL ZXSROT(IWTROT)
-      IF (IWS.EQ.2) CALL Z1SROT(IWTROT)
-      IF (IWS.EQ.3) CALL ZTSROT(IWTROT)
-      IF (IWS.EQ.4) CALL ZGSROT(IWTROT)
+      CALL ZGSROT(IWTROT)
 
       RETURN
-
 *-----------------------------------------------------------------------
       ENTRY SWCLCH()
 
@@ -563,10 +428,7 @@
         CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXIST.')
       END IF
 
-      IF (IWS.EQ.1) CALL ZXCLINI(CLRMAP,LFGBG)
-      IF (IWS.EQ.2) CALL Z1CLINI(CLRMAP)
-*      IF (IWS.EQ.3) CALL ZTCLINI(CLRMAP,LFGBG)
-      IF (IWS.EQ.4) CALL ZGCLINI(CLRMAP,LFGBG)
+      CALL ZGCLINI(CLRMAP,LFGBG)
 
       RETURN
 
