@@ -1,5 +1,7 @@
 *-----------------------------------------------------------------------
 *     UMSPDF : DEFAULT
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE UMSPDF
 
@@ -21,12 +23,12 @@
 
       IF (ITR.EQ.20 .OR. ITR.EQ.21 .OR. ITR.EQ.23) THEN
         IF (STLAT1 .EQ. RUNDEF) STLAT1 = CPD*35
-        CALL SGPSET('STLAT1',STLAT1)
+        CALL SGRSET('STLAT1',STLAT1)
       ELSE IF (ITR .EQ. 22) THEN
         IF (STLAT1 .EQ. RUNDEF) STLAT1 = CPD*35
         IF (STLAT2 .EQ. RUNDEF) STLAT2 = CPD*45
-        CALL SGPSET('STLAT1', STLAT1)
-        CALL SGPSET('STLAT2', STLAT2)
+        CALL SGRSET('STLAT1', STLAT1)
+        CALL SGRSET('STLAT2', STLAT2)
       END IF
 
       END
