@@ -27,9 +27,15 @@ static void free_2d(float **b)
 }
 
 /*--- PUBLIC ---*/
+#ifndef WINDOWS
 void g2qgrd_(DCL_INT *i, DCL_INT *j, 
              DCL_REAL *cx11, DCL_REAL *cx21, DCL_REAL *cx12, DCL_REAL *cx22, 
              DCL_REAL *cy11, DCL_REAL *cy21, DCL_REAL *cy12, DCL_REAL *cy22)
+#else
+void G2QGRD(DCL_INT *i, DCL_INT *j, 
+             DCL_REAL *cx11, DCL_REAL *cx21, DCL_REAL *cx12, DCL_REAL *cx22, 
+             DCL_REAL *cy11, DCL_REAL *cy21, DCL_REAL *cy12, DCL_REAL *cy22)
+#endif
 {
     /* NOTE: C indices are 1 smaller than Fortran indices */
     *cx11 = cxs[*j-1][*i-1];
@@ -42,9 +48,15 @@ void g2qgrd_(DCL_INT *i, DCL_INT *j,
     *cy22 = cys[*j][*i];
 }
 
+#ifndef WINDOWS
 void g2sgrd_(DCL_REAL *rundef, 
              DCL_INT *iuxinc, DCL_INT *iuyinc, DCL_INT *nx, DCL_INT *ny, 
              DCL_REAL *cx, DCL_REAL *cy, DCL_REAL *uxs, DCL_REAL *uys)
+#else
+void G2SGRD(DCL_REAL *rundef, 
+             DCL_INT *iuxinc, DCL_INT *iuyinc, DCL_INT *nx, DCL_INT *ny, 
+             DCL_REAL *cx, DCL_REAL *cy, DCL_REAL *uxs, DCL_REAL *uys)
+#endif
 {
     static int first = 1;
     int i,j;
