@@ -9,15 +9,17 @@
       CHARACTER CPFIX*(*), CP*(*), CPARA*(*)
 
       LOGICAL   LFROMC
-      CHARACTER CARG*80, CPX*16, CSEP*1
+      CHARACTER CARG*80, CPX*16, CSEP*1, CSEPX*1
 
       EXTERNAL  LENC,IFROMC,LFROMC,RFROMC
 
       SAVE
 
+      DATA      CSEPX / '_' /
+
 
       CALL OSGENV('DCLENVCHAR',CSEP)
-      IF (CSEP.EQ.' ') CSEP=':'
+      IF (CSEP.EQ.' ') CSEP=CSEPX
 
       RETURN
 *-----------------------------------------------------------------------
