@@ -8,7 +8,11 @@
 #include <time.h>
 #include "../../../config.h"
 
+#ifndef WINDOWS
 void dateq3_(DCL_INT *iy, DCL_INT *im, DCL_INT *id)
+#else
+void DATEQ3(DCL_INT *iy, DCL_INT *im, DCL_INT *id)
+#endif
 {
     long tp;
     struct tm lt;
