@@ -8,7 +8,11 @@
 #include <time.h>
 #include "../../../config.h"
 
+#ifndef WINDOWS
 void timeq3_(DCL_INT *ih, DCL_INT *im, DCL_INT *is)
+#else
+void TIMEQ3(DCL_INT *ih, DCL_INT *im, DCL_INT *is)
+#endif
 {
     long tp;
     struct tm lt;
